@@ -2,7 +2,7 @@
 #
 # Updates lists of translations in various places
 #
-# $Id: update-translation-lists.sh 1191 2007-11-14 11:01:22Z vaclavslavik $
+# $Id: update-translation-lists.sh 1326 2008-02-28 12:16:50Z vaclavslavik $
 #
 
 LANGS_POEDIT=`ls *.po 2>/dev/null | sed -n 's,\.po,,p'`
@@ -11,7 +11,7 @@ LANGS_POEDIT=`echo $LANGS_POEDIT`
 replace_str()
 {
     echo "
-,s@$2@$3@g
+,s;$2;$3;g
 w
 q
 " | ed -s $1 2>/dev/null
