@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp 1183 2007-11-09 10:36:00Z vaclavslavik $
+ *  $Id: catalog.cpp 1314 2008-02-25 22:53:26Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -849,7 +849,7 @@ bool LoadParser::OnEntry(const wxString& msgid,
     }
     else
     {
-        CatalogData d;
+        CatalogItem d;
         if (!flags.empty()) d.SetFlags(flags);
         d.SetString(msgid);
         if (has_plural)
@@ -1071,7 +1071,7 @@ bool Catalog::Load(const wxString& po_file)
     return true;
 }
 
-void Catalog::AddItem(const CatalogData& data)
+void Catalog::AddItem(const CatalogItem& data)
 {
     m_items.push_back(data);
 }
@@ -1233,9 +1233,12 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
 
     GetCRLFBehaviour(crlfOrig, crlfPreserve);
 
-    /* Update information about last modification time: */
-
-    m_header.RevisionDate = GetCurrentTimeRFC822();
+    // Update information about last modification time. But if the header
+    // was empty previously, the author apparently doesn't want this header
+    // set, so don't mess with it. See https://sourceforge.net/tracker/?func=detail&atid=389156&aid=1900298&group_id=27043
+    // for motivation:
+    if ( !m_header.RevisionDate.empty() )
+        m_header.RevisionDate = GetCurrentTimeRFC822();
 
     /* Detect CRLF format: */
 
@@ -1288,7 +1291,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
 
     for (unsigned i = 0; i < m_items.size(); i++)
     {
-        CatalogData& data = m_items[i];
+        CatalogItem& data = m_items[i];
         SaveMultiLines(f, data.GetComment());
         for (unsigned i = 0; i < data.GetAutoComments().GetCount(); i++)
         {
@@ -1497,7 +1500,7 @@ void Catalog::GetMergeSummary(Catalog *refcat,
                               wxArrayString& snew, wxArrayString& sobsolete)
 {
     wxASSERT( snew.empty() );
-    wxASSERT( sbsolete.empty() );
+    wxASSERT( sobsolete.empty() );
 
     std::set<wxString> strsThis, strsRef;
 
@@ -1568,7 +1571,7 @@ void Catalog::GetStatistics(int *all, int *fuzzy, int *badtokens, int *untransla
         if (all) (*all)++;
         if ((*this)[i].IsFuzzy())
             (*fuzzy)++;
-        if ((*this)[i].GetValidity() == CatalogData::Val_Invalid)
+        if ((*this)[i].GetValidity() == CatalogItem::Val_Invalid)
             (*badtokens)++;
         if (!(*this)[i].IsTranslated())
             (*untranslated)++;
@@ -1576,7 +1579,7 @@ void Catalog::GetStatistics(int *all, int *fuzzy, int *badtokens, int *untransla
 }
 
 
-void CatalogData::SetFlags(const wxString& flags)
+void CatalogItem::SetFlags(const wxString& flags)
 {
     m_isFuzzy = false;
     m_moreFlags.Empty();
@@ -1593,7 +1596,7 @@ void CatalogData::SetFlags(const wxString& flags)
 }
 
 
-wxString CatalogData::GetFlags() const
+wxString CatalogItem::GetFlags() const
 {
     wxString f;
     if (m_isFuzzy) f << _T(", fuzzy");
@@ -1604,7 +1607,7 @@ wxString CatalogData::GetFlags() const
         return wxEmptyString;
 }
 
-bool CatalogData::IsInFormat(const wxString& format)
+bool CatalogItem::IsInFormat(const wxString& format)
 {
     wxString lookingFor;
     lookingFor.Printf(_T("%s-format"), format.c_str());
@@ -1617,7 +1620,7 @@ bool CatalogData::IsInFormat(const wxString& format)
     return false;
 }
 
-wxString CatalogData::GetTranslation(unsigned idx) const
+wxString CatalogItem::GetTranslation(unsigned idx) const
 {
     if (idx >= GetNumberOfTranslations())
         return wxEmptyString;
@@ -1625,28 +1628,40 @@ wxString CatalogData::GetTranslation(unsigned idx) const
         return m_translations[idx];
 }
 
-void CatalogData::SetTranslation(const wxString &t, unsigned idx)
+void CatalogItem::SetTranslation(const wxString &t, unsigned idx)
 {
     while (idx >= m_translations.GetCount())
         m_translations.Add(wxEmptyString);
     m_translations[idx] = t;
 
     m_validity = Val_Unknown;
-    m_isTranslated = false;
+
+    m_isTranslated = true;
     for (size_t i = 0; i < m_translations.GetCount(); i++)
-        if (!m_translations[i].empty())
-            m_isTranslated = true;
+    {
+        if (m_translations[i].empty())
+        {
+            m_isTranslated = false;
+            break;
+        }
+    }
 }
 
-void CatalogData::SetTranslations(const wxArrayString &t)
+void CatalogItem::SetTranslations(const wxArrayString &t)
 {
     m_translations = t;
 
     m_validity = Val_Unknown;
-    m_isTranslated = false;
+
+    m_isTranslated = true;
     for (size_t i = 0; i < m_translations.GetCount(); i++)
-        if (!m_translations[i].empty())
-            m_isTranslated = true;
+    {
+        if (m_translations[i].empty())
+        {
+            m_isTranslated = false;
+            break;
+        }
+    }
 }
 
 
