@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: chooselang.cpp 1216 2007-11-24 10:25:15Z vaclavslavik $
+ *  $Id: chooselang.cpp 1357 2008-03-03 22:23:37Z vaclavslavik $
  *
  *  Language chooser
  *
@@ -79,7 +79,7 @@ wxLanguage ChooseLanguage()
 {
     struct LangInfo
     {
-        const wxChar *name;
+        wxString name;
         wxLanguage code;
     };
 
@@ -149,12 +149,11 @@ wxLanguage ChooseLanguage()
         { _T("Turkish"), wxLANGUAGE_TURKISH },
         { _T("Ukrainian"), wxLANGUAGE_UKRAINIAN },
         { _T("Urdu"), wxLANGUAGE_URDU },
-
-        { NULL, wxLANGUAGE_UNKNOWN }
+        { _T(""), wxLANGUAGE_UNKNOWN }
     };
 
     wxArrayString arr;
-    for (int i = 0; langs[i].name; i++)
+    for (int i = 0; !langs[i].name.empty(); i++)
         arr.Add(langs[i].name);
 
     int choice = wxGetSingleChoiceIndex(
