@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: digger.cpp 1180 2007-11-07 09:31:51Z vaclavslavik $
+ *  $Id: digger.cpp 1360 2008-03-07 10:22:23Z vaclavslavik $
  *
  *  Sources digging class (xgettext)
  *
@@ -55,7 +55,7 @@ wxString ConcatCatalogs(const wxArrayString& files)
     }
 
     wxString cmd =
-        wxString::Format(_T("msgcat --force-po -o \"%s\" %s"),
+        wxString::Format(_T("msgcat --force-po --use-first -o \"%s\" %s"),
                          tempfile.c_str(),
                          list.c_str());
     bool succ = ExecuteGettext(cmd);
