@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2000-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: digger.h 1066 2007-03-21 17:27:08Z vaclavslavik $
+ *  $Id: digger.h 1180 2007-11-07 09:31:51Z vaclavslavik $
  *
  *  Sources digging class (xgettext)
  *
@@ -79,13 +79,15 @@ class SourceDigger
         bool FindInDir(const wxString& dirname, wxArrayString& files);
 
         /** Digs translatable strings from given files.
-            \param cat      the catalog to store found strings to
+            \param outfiles list to which (temporary) file name of extracted
+                            catalog will be appended
             \param files    list of files to parse
             \param parser   parser definition
             \param keywords list of keywords that mark translatable strings
             \param charset  source code charset (may be empty)
          */
-        bool DigFiles(Catalog *cat, const wxArrayString& files, 
+        bool DigFiles(wxArrayString& outFiles,
+                      const wxArrayString& files,
                       Parser &parser, const wxArrayString& keywords,
                       const wxString& charset);
 
