@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2005 Vaclav Slavik
+ *  Copyright (C) 1999-2008 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edframe.h 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: edframe.h 1316 2008-02-26 13:16:52Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -38,7 +38,11 @@
 // processes doesn't work well:
 #define USE_GETTEXT_VALIDATION 0
 
+#if USE_GETTEXT_VALIDATION
 #include <list>
+#endif
+
+#include <set>
 
 #include <wx/frame.h>
 #include <wx/docview.h>
@@ -62,6 +66,7 @@ class WXDLLEXPORT wxStaticText;
 
 class ListHandler;
 class TextctrlHandler;
+class TransTextctrlHandler;
 
 class TranslationMemory;
 class PoeditFrame;
@@ -121,10 +126,13 @@ class PoeditFrame : public wxFrame
         void RefreshControls();
         /// Sets controls custom fonts.
         void SetCustomFonts();
+
+        CatalogItem *GetCurrentItem() const;
+
         /// Puts text from textctrls to catalog & listctrl.
-        void UpdateFromTextCtrl(int item = -1);
+        void UpdateFromTextCtrl();
         /// Puts text from catalog & listctrl to textctrls.
-        void UpdateToTextCtrl(int item = -1);
+        void UpdateToTextCtrl();
 
         /// Updates statistics in statusbar.
         void UpdateStatusBar();
@@ -166,7 +174,6 @@ class PoeditFrame : public wxFrame
         void OnPreferences(wxCommandEvent& event);
         void OnUpdate(wxCommandEvent& event);
         void OnListSel(wxListEvent& event);
-        void OnListDesel(wxListEvent& event);
         void OnListActivated(wxListEvent& event);
         void OnListRightClick(wxMouseEvent& event);
         void OnListFocus(wxFocusEvent& event);
@@ -225,6 +232,8 @@ class PoeditFrame : public wxFrame
         void InitHelp();
         wxString LoadHelpBook(const wxString& name);
 
+        void RefreshSelectedItem();
+
         DECLARE_EVENT_TABLE()
 
     private:
@@ -240,6 +249,8 @@ class PoeditFrame : public wxFrame
         ValidationProcessData m_validationProcess;
 #endif
 
+        std::set<int> m_itemsRefreshQueue;
+
         bool m_commentWindowEditable;
         Catalog *m_catalog;
         wxString m_fileName;
@@ -277,13 +288,12 @@ class PoeditFrame : public wxFrame
         bool m_displayLines;
         bool m_displayCommentWin;
         bool m_displayAutoCommentsWin;
-        int m_sel;//, m_selItem;
         wxFileHistory m_history;
-        std::vector<wxString> m_edittedTextOrig;
-        bool m_edittedTextFuzzyChanged;
+        bool m_dontAutoclearFuzzyStatus;
 
         friend class ListHandler;
         friend class TextctrlHandler;
+        friend class TransTextctrlHandler;
 };
 
 
