@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2007 Vaclav Slavik
+ *  Copyright (C) 1999-2008 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.cpp 1248 2007-12-09 13:25:08Z vaclavslavik $
+ *  $Id: edlistctrl.cpp 1358 2008-03-04 10:40:09Z vaclavslavik $
  *
  *  List view control
  *
@@ -38,21 +38,48 @@
 #include "digits.h"
 
 // I don't like this global flag, but all PoeditFrame instances should share it :(
-bool gs_shadedList = false;
+bool g_shadedList = false;
+
+namespace
+{
+
+// how much to darken the other color in shaded list (this value
+// is what GTK+ uses in its tree view control)
+#define DARKEN_FACTOR      0.95
+
+// max difference in color to consider it "amost" same if it differs by most
+// this amount (in 0..255 range) from the tested color:
+#define COLOR_SIMILARITY_FACTOR  20
+
+inline bool IsAlmostBlack(const wxColour& clr)
+{
+    return (clr.Red() <= COLOR_SIMILARITY_FACTOR &&
+            clr.Green() <= COLOR_SIMILARITY_FACTOR &&
+            clr.Blue() <= COLOR_SIMILARITY_FACTOR);
+}
+
+inline bool IsAlmostWhite(const wxColour& clr)
+{
+    return (clr.Red() >= 255-COLOR_SIMILARITY_FACTOR &&
+            clr.Green() >= 255-COLOR_SIMILARITY_FACTOR &&
+            clr.Blue() >= 255-COLOR_SIMILARITY_FACTOR);
+}
+
 
 // colours used in the list:
-#define g_darkColourFactor 0.95
-#define DARKEN_COLOUR(r,g,b) (wxColour(int((r)*g_darkColourFactor),\
-                                       int((g)*g_darkColourFactor),\
-                                       int((b)*g_darkColourFactor)))
-#define LIST_COLOURS(r,g,b) { wxColour(r,g,b), DARKEN_COLOUR(r,g,b) }
-static const wxColour
-    g_ItemColourNormal[2] =       LIST_COLOURS(0xFF,0xFF,0xFF), // white
-    g_ItemColourUntranslated[2] = LIST_COLOURS(0xA5,0xEA,0xEF), // blue
-    g_ItemColourFuzzy[2] =        LIST_COLOURS(0xF4,0xF1,0xC1), // yellow
-    g_ItemColourInvalid[2] =      LIST_COLOURS(0xFF,0x20,0x20); // red
 
-static const wxColour g_TranspColour(254, 0, 253);
+const wxColour gs_ErrorColor(_T("#ff0000"));
+
+// colors for white list control background
+const wxColour gs_UntranslatedForWhite(_T("#103f67"));
+const wxColour gs_FuzzyForWhite(_T("#a9861b"));
+
+// ditto for black background
+const wxColour gs_UntranslatedForBlack(_T("#1962a0"));
+const wxColour gs_FuzzyForBlack(_T("#a9861b"));
+
+
+const wxColour gs_TranspColor(254, 0, 253); // FIXME: get rid of this
 
 enum
 {
@@ -72,12 +99,8 @@ enum
     IMG_BK9       = 10 << 3
 };
 
-BEGIN_EVENT_TABLE(PoeditListCtrl, wxListCtrl)
-   EVT_SIZE(PoeditListCtrl::OnSize)
-END_EVENT_TABLE()
 
-
-static wxBitmap AddDigit(int digit, int x, int y, const wxBitmap& bmp)
+wxBitmap AddDigit(int digit, int x, int y, const wxBitmap& bmp)
 {
     wxMemoryDC dc;
     int width = bmp.GetWidth();
@@ -85,7 +108,7 @@ static wxBitmap AddDigit(int digit, int x, int y, const wxBitmap& bmp)
     wxBitmap tmpBmp(width, height);
     dc.SelectObject(tmpBmp);
     dc.SetPen(*wxTRANSPARENT_PEN);
-    dc.SetBrush(wxBrush(g_TranspColour, wxSOLID));
+    dc.SetBrush(wxBrush(gs_TranspColor, wxSOLID));
     dc.DrawRectangle(0, 0, width, height);
 
     dc.DrawBitmap(bmp, 0,0,true);
@@ -101,7 +124,7 @@ static wxBitmap AddDigit(int digit, int x, int y, const wxBitmap& bmp)
     }
 
     dc.SelectObject(wxNullBitmap);
-    tmpBmp.SetMask(new wxMask(tmpBmp, g_TranspColour));
+    tmpBmp.SetMask(new wxMask(tmpBmp, gs_TranspColor));
     return tmpBmp;
 }
 
@@ -112,13 +135,13 @@ wxBitmap MergeBitmaps(const wxBitmap& bmp1, const wxBitmap& bmp2)
 
     dc.SelectObject(tmpBmp);
     dc.SetPen(*wxTRANSPARENT_PEN);
-    dc.SetBrush(wxBrush(g_TranspColour, wxSOLID));
+    dc.SetBrush(wxBrush(gs_TranspColor, wxSOLID));
     dc.DrawRectangle(0, 0, bmp1.GetWidth(), bmp1.GetHeight());
     dc.DrawBitmap(bmp1, 0, 0, true);
     dc.DrawBitmap(bmp2, 0, 0, true);
     dc.SelectObject(wxNullBitmap);
 
-    tmpBmp.SetMask(new wxMask(tmpBmp, g_TranspColour));
+    tmpBmp.SetMask(new wxMask(tmpBmp, gs_TranspColor));
     return tmpBmp;
 }
 
@@ -130,16 +153,23 @@ wxBitmap BitmapFromList(wxImageList* list, int index)
     wxBitmap bmp(width, height);
     dc.SelectObject(bmp);
     dc.SetPen(*wxTRANSPARENT_PEN);
-    dc.SetBrush(wxBrush(g_TranspColour, wxSOLID));
+    dc.SetBrush(wxBrush(gs_TranspColor, wxSOLID));
     dc.DrawRectangle(0, 0, width, height);
 
     list->Draw(index, dc, 0, 0, wxIMAGELIST_DRAW_TRANSPARENT);
 
     dc.SelectObject(wxNullBitmap);
-    bmp.SetMask(new wxMask(bmp, g_TranspColour));
+    bmp.SetMask(new wxMask(bmp, gs_TranspColor));
     return bmp;
 }
 
+} // anonymous namespace
+
+
+BEGIN_EVENT_TABLE(PoeditListCtrl, wxListCtrl)
+   EVT_SIZE(PoeditListCtrl::OnSize)
+END_EVENT_TABLE()
+
 PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
                wxWindowID id,
                const wxPoint &pos,
@@ -190,21 +220,69 @@ PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
 
     AssignImageList(list, wxIMAGE_LIST_SMALL);
 
-    // configure items colors:
-    m_attrNormal[0].SetBackgroundColour(g_ItemColourNormal[0]);
-    m_attrNormal[1].SetBackgroundColour(g_ItemColourNormal[1]);
-    m_attrUntranslated[0].SetBackgroundColour(g_ItemColourUntranslated[0]);
-    m_attrUntranslated[1].SetBackgroundColour(g_ItemColourUntranslated[1]);
-    m_attrFuzzy[0].SetBackgroundColour(g_ItemColourFuzzy[0]);
-    m_attrFuzzy[1].SetBackgroundColour(g_ItemColourFuzzy[1]);
-    m_attrInvalid[0].SetBackgroundColour(g_ItemColourInvalid[0]);
-    m_attrInvalid[1].SetBackgroundColour(g_ItemColourInvalid[1]);
+    // configure items colors & fonts:
+
+    wxVisualAttributes visual = GetDefaultAttributes();
+    wxColour shaded = visual.colBg;
+    shaded.Set(int(DARKEN_FACTOR * shaded.Red()),
+               int(DARKEN_FACTOR * shaded.Green()),
+               int(DARKEN_FACTOR * shaded.Blue()));
+
+    m_attrNormal[1].SetBackgroundColour(shaded);
+    m_attrUntranslated[1].SetBackgroundColour(shaded);
+    m_attrFuzzy[1].SetBackgroundColour(shaded);
+    m_attrInvalid[1].SetBackgroundColour(shaded);
+
+    // FIXME: make this user-configurable
+    if ( IsAlmostWhite(visual.colBg) )
+    {
+        m_attrUntranslated[0].SetTextColour(gs_UntranslatedForWhite);
+        m_attrUntranslated[1].SetTextColour(gs_UntranslatedForWhite);
+        m_attrFuzzy[0].SetTextColour(gs_FuzzyForWhite);
+        m_attrFuzzy[1].SetTextColour(gs_FuzzyForWhite);
+    }
+    else if ( IsAlmostBlack(visual.colBg) )
+    {
+        m_attrUntranslated[0].SetTextColour(gs_UntranslatedForBlack);
+        m_attrUntranslated[1].SetTextColour(gs_UntranslatedForBlack);
+        m_attrFuzzy[0].SetTextColour(gs_FuzzyForBlack);
+        m_attrFuzzy[1].SetTextColour(gs_FuzzyForBlack);
+    }
+    // else: we don't know if the default colors would be well-visible on
+    //       user's background color, so play it safe and don't highlight
+    //       anything
+
+    // FIXME: todo; use appropriate font for fuzzy/trans/untrans
+    m_attrInvalid[0].SetTextColour(gs_ErrorColor);
+    m_attrInvalid[1].SetTextColour(gs_ErrorColor);
+
+    SetCustomFont(wxNullFont);
 }
 
 PoeditListCtrl::~PoeditListCtrl()
 {
 }
 
+void PoeditListCtrl::SetCustomFont(wxFont font_)
+{
+    wxFont font(font_);
+
+    m_attrNormal[0].SetFont(font);
+    m_attrNormal[1].SetFont(font);
+
+    if ( !font.IsOk() )
+        font = GetDefaultAttributes().font;
+
+    wxFont fontb = font;
+    fontb.SetWeight(wxFONTWEIGHT_BOLD);
+
+    m_attrUntranslated[0].SetFont(fontb);
+    m_attrUntranslated[1].SetFont(fontb);
+
+    m_attrFuzzy[0].SetFont(fontb);
+    m_attrFuzzy[1].SetFont(fontb);
+}
+
 void PoeditListCtrl::SetDisplayLines(bool dl)
 {
     m_displayLines = dl;
@@ -273,10 +351,10 @@ void PoeditListCtrl::ReadCatalog()
 
     for (size_t i = 0; i < m_catalog->GetCount(); i++)
     {
-        CatalogData& d = (*m_catalog)[i];
+        CatalogItem& d = (*m_catalog)[i];
         if (!d.IsTranslated())
           untranslatedIds.push_back(i);
-        else if (d.GetValidity() == CatalogData::Val_Invalid)
+        else if (d.GetValidity() == CatalogItem::Val_Invalid)
           invalidIds.push_back(i);
         else if (d.IsFuzzy())
           fuzzyIds.push_back(i);
@@ -315,8 +393,15 @@ void PoeditListCtrl::ReadCatalog()
     SetItemCount(m_catalog->GetCount());
 
     // scroll to the top and refresh everything:
-    Select(0);
-    RefreshItems(0, m_catalog->GetCount());
+    if ( m_catalog->GetCount() )
+    {
+        Select(0);
+        RefreshItems(0, m_catalog->GetCount()-1);
+    }
+    else
+    {
+        Refresh();
+    }
 }
 
 wxString PoeditListCtrl::OnGetItemText(long item, long column) const
@@ -324,7 +409,7 @@ wxString PoeditListCtrl::OnGetItemText(long item, long column) const
     if (m_catalog == NULL)
         return wxEmptyString;
 
-    CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
+    CatalogItem& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
     switch (column)
     {
         case 0:
@@ -347,18 +432,18 @@ wxString PoeditListCtrl::OnGetItemText(long item, long column) const
 
 wxListItemAttr *PoeditListCtrl::OnGetItemAttr(long item) const
 {
-    size_t idx = gs_shadedList ? size_t(item % 2) : 0;
+    size_t idx = g_shadedList ? size_t(item % 2) : 0;
 
     if (m_catalog == NULL)
         return (wxListItemAttr*)&m_attrNormal[idx];
 
-    CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
+    CatalogItem& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
 
     if (!d.IsTranslated())
         return (wxListItemAttr*)&m_attrUntranslated[idx];
     else if (d.IsFuzzy())
         return (wxListItemAttr*)&m_attrFuzzy[idx];
-    else if (d.GetValidity() == CatalogData::Val_Invalid)
+    else if (d.GetValidity() == CatalogItem::Val_Invalid)
         return (wxListItemAttr*)&m_attrInvalid[idx];
     else
         return (wxListItemAttr*)&m_attrNormal[idx];
@@ -369,7 +454,7 @@ int PoeditListCtrl::OnGetItemImage(long item) const
     if (m_catalog == NULL)
         return IMG_NOTHING;
 
-    CatalogData& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
+    CatalogItem& d = (*m_catalog)[m_itemIndexToCatalogIndexArray[item]];
     int index = IMG_NOTHING;
 
     if (d.IsAutomatic())
