@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: findframe.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: findframe.cpp 1395 2008-04-05 13:17:06Z vaclavslavik $
  *
  *  Search frame
  *
@@ -42,6 +42,8 @@
 // The word separators used when doing a "Whole words only" search
 static const wxString SEPARATORS = wxT(" \t\r\n\\/:;.,?!\"'_|-+=(){}[]<>&#@");
 
+wxString FindFrame::ms_text;
+
 BEGIN_EVENT_TABLE(FindFrame, wxFrame)
    EVT_BUTTON(XRCID("find_next"), FindFrame::OnNext)
    EVT_BUTTON(XRCID("find_prev"), FindFrame::OnPrev)
@@ -76,6 +78,13 @@ FindFrame::FindFrame(wxWindow *parent,
     m_btnNext = XRCCTRL(*this, "find_next", wxButton);
     m_btnPrev = XRCCTRL(*this, "find_prev", wxButton);
 
+    if ( !ms_text.empty() )
+    {
+        wxTextCtrl *t = XRCCTRL(*this, "string_to_find", wxTextCtrl);
+        t->SetValue(ms_text);
+        t->SelectAll();
+    }
+
     Reset(c);
 
     XRCCTRL(*this, "in_orig", wxCheckBox)->SetValue(
@@ -128,8 +137,8 @@ void FindFrame::Reset(Catalog *c)
                                              wxLIST_NEXT_ALL,
                                              wxLIST_STATE_SELECTED);
 
-    m_btnPrev->Enable(!!m_text);
-    m_btnNext->Enable(!!m_text);
+    m_btnPrev->Enable(!ms_text.empty());
+    m_btnNext->Enable(!ms_text.empty());
 }
 
 
@@ -146,7 +155,7 @@ void FindFrame::OnCancel(wxCommandEvent &event)
 
 void FindFrame::OnTextChange(wxCommandEvent &event)
 {
-    m_text = XRCCTRL(*this, "string_to_find", wxTextCtrl)->GetValue();
+    ms_text = XRCCTRL(*this, "string_to_find", wxTextCtrl)->GetValue();
     Reset(m_catalog);
 }
 
@@ -225,7 +234,7 @@ bool FindFrame::DoFind(int dir)
 
     FoundState found = Found_Not;
     wxString textc;
-    wxString text(m_text);
+    wxString text(ms_text);
 
     if (!caseSens)
         text.MakeLower();
@@ -233,7 +242,7 @@ bool FindFrame::DoFind(int dir)
     m_position += dir;
     while (m_position >= 0 && m_position < cnt)
     {
-        CatalogData &dt = (*m_catalog)[m_listCtrl->GetIndexInCatalog(m_position)];
+        CatalogItem &dt = (*m_catalog)[m_listCtrl->GetIndexInCatalog(m_position)];
 
         if (inStr)
         {
