@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: findframe.h 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: findframe.h 1395 2008-04-05 13:17:06Z vaclavslavik $
  *
  *  Search frame
  *
@@ -75,10 +75,12 @@ class FindFrame : public wxFrame
         PoeditListCtrl *m_listCtrl;
         Catalog *m_catalog;
         int m_position;
-        wxString m_text;
         wxButton *m_btnPrev, *m_btnNext;
         wxTextCtrl *m_textCtrlOrig, *m_textCtrlTrans;
         wxTextCtrl *m_textCtrlComments, *m_textCtrlAutoComments;
+
+        // NB: this is static so that last search term is remembered
+        static wxString ms_text;
 };
 
 
