@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: gexecute.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: gexecute.cpp 1441 2008-08-03 17:07:08Z vaclavslavik $
  *
  *  Gettext execution code
  *
@@ -125,27 +125,31 @@ class TempLocaleSwitcher
 #ifdef __WXMAC__
 static wxString MacGetPathToBinary(const wxString& program)
 {
-    wxMacUniCharBuffer programbuf(program);
-    wxMacCFStringHolder programstr(
-        CFStringCreateWithCharacters(NULL,
-                                     programbuf.GetBuffer(),
-                                     programbuf.GetChars()));
+#if !wxCHECK_VERSION(2,9,0)
+    #define wxCFStringRef wxMacCFStringHolder
+#endif
+    wxCFStringRef programstr(program);
 
     CFBundleRef bundle = CFBundleGetMainBundle();
     CFURLRef urlRel = CFBundleCopyAuxiliaryExecutableURL(bundle, programstr);
 
     if ( urlRel == NULL )
+    {
+        wxLogTrace(_T("poedit.execute"), _T("failed to locate '%s'"), program.c_str());
         return program;
+    }
 
     CFURLRef urlAbs = CFURLCopyAbsoluteURL(urlRel);
 
-    wxMacCFStringHolder path(
-            CFURLCopyFileSystemPath(urlAbs, kCFURLPOSIXPathStyle));
+    wxCFStringRef path(CFURLCopyFileSystemPath(urlAbs, kCFURLPOSIXPathStyle));
 
     CFRelease(urlRel);
     CFRelease(urlAbs);
 
-    return path.AsString(wxLocale::GetSystemEncoding());
+    wxString full = path.AsString(wxLocale::GetSystemEncoding());
+    wxLogTrace(_T("poedit.execute"), _T("using '%s'"), full.c_str());
+
+    return wxString::Format(_T("\"%s\""), full.c_str());
 }
 #endif // __WXMAC__
 
