@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 2004-2006 Vaclav Slavik
+ *  Copyright (C) 2004-2008 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: icons.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: icons.cpp 1344 2008-03-01 20:46:07Z vaclavslavik $
  *
  *  Art provider classes
  *
@@ -33,10 +33,6 @@
 #include "icons.h"
 #include "edapp.h"
 
-#ifdef __UNIX__
-#include "icons/appicon/poedit.xpm"
-#endif
-
 #ifdef __WXGTK20__
 // translates poedit item id or Tango stock item id to "legacy" GNOME id:
 static wxString GetGnomeStockId(const wxString& id)
@@ -59,48 +55,18 @@ static wxString GetGnomeStockId(const wxString& id)
 #endif // __WXGTK20__
 
 
-// wxWidgets prior to 2.7.1 didn't have wxArtProvider::InsertProvider() and
-// so it wasn't possibly to add a provider that would be used as the last
-// resort. Unfortunately that's exactly what we need: use the stock (GTK2)
-// provider to try to look up poedit icons in the theme (so that themes
-// may override them) and only if that fails, use the Tango icons shipped
-// with poedit. So we use a hack instead: temporarily disable this provider
-// and re-run the lookup from its CreateBitmap, thus getting the bitmap from
-// providers lower on the stack:
-#if defined(HAS_THEMES_SUPPORT) && !defined(HAS_INSERT_PROVIDER)
-    #define USE_THEME_HACK
-#endif
-
-#ifdef USE_THEME_HACK
-static bool gs_disablePoeditProvider = false;
-#endif
-
-
 wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id,
                                          const wxArtClient& client,
                                          const wxSize& size)
 {
-#ifdef USE_THEME_HACK
-    if ( gs_disablePoeditProvider )
-        return wxNullBitmap;
-
-    // try to get the icon from theme provider:
-    gs_disablePoeditProvider = true;
-    wxBitmap hackbmp = wxArtProvider::GetBitmap(id, client, size);
-    gs_disablePoeditProvider = false;
-    if ( hackbmp.Ok() )
-        return hackbmp;
-#endif // USE_THEME_HACK
+    // Note: On Unix, this code is only called as last resolt, if standard
+    //       theme provider (that uses current icon theme and files from
+    //       /usr/share/icons/<theme>) didn't find any matching icon.
 
     wxLogTrace(_T("poedit.icons"), _T("getting icon '%s'"), id.c_str());
 
-#ifdef __UNIX__
-    if (id == _T("poedit"))
-        return wxBitmap(appicon_xpm);
-#endif
-
 #ifdef __WXGTK20__
-    // try legacy GNOME icons:
+    // try legacy GNOME icons from standard theme:
     wxString gnomeId = GetGnomeStockId(id);
     if ( !gnomeId.empty() )
     {
