@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: icons.h 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: icons.h 1342 2008-03-01 20:27:52Z vaclavslavik $
  *
  *  Art provider classes
  *
@@ -36,11 +36,6 @@
     #define HAS_THEMES_SUPPORT
 #endif
 
-// see icons.cpp for explanation
-#if wxCHECK_VERSION(2,7,1)
-    #define HAS_INSERT_PROVIDER
-#endif
-
 class PoeditArtProvider : public wxArtProvider
 {
 protected:
