@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 2001-2005 Vaclav Slavik
+ *  Copyright (C) 2001-2008 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: manager.cpp 1237 2007-12-02 21:18:34Z vaclavslavik $
+ *  $Id: manager.cpp 1356 2008-03-03 15:14:33Z vaclavslavik $
  *
  *  Catalogs manager frame
  *
@@ -47,6 +47,7 @@
 #include <wx/dirdlg.h>
 #include <wx/log.h>
 #include <wx/artprov.h>
+#include <wx/iconbndl.h>
 
 #include "catalog.h"
 #include "edframe.h"
@@ -66,26 +67,20 @@ ManagerFrame *ManagerFrame::ms_instance = NULL;
 }
 
 ManagerFrame::ManagerFrame() :
-    wxFrame(NULL, -1, _("Poedit - Catalogs manager"), wxPoint(
-                                 wxConfig::Get()->Read(_T("manager_x"), -1),
-                                 wxConfig::Get()->Read(_T("manager_y"), -1)),
-                             wxSize(
-                                 wxConfig::Get()->Read(_T("manager_w"), 400),
-                                 wxConfig::Get()->Read(_T("manager_h"), 300)),
-                             wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE)
+    wxFrame(NULL, -1, _("Poedit - Catalogs manager"),
+            wxDefaultPosition, wxDefaultSize,
+            wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE)
 {
 #ifdef __UNIX__
-    SetIcon(wxArtProvider::GetIcon(_T("poedit")));
+    wxIconBundle appicons;
+    appicons.AddIcon(wxArtProvider::GetIcon(_T("poedit"), wxART_FRAME_ICON, wxSize(16,16)));
+    appicons.AddIcon(wxArtProvider::GetIcon(_T("poedit"), wxART_FRAME_ICON, wxSize(32,32)));
+    appicons.AddIcon(wxArtProvider::GetIcon(_T("poedit"), wxART_FRAME_ICON, wxSize(48,48)));
+    SetIcons(appicons);
 #else
     SetIcon(wxICON(appicon));
 #endif
 
-#if !defined(__WXGTK12__) || defined(__WXGTK20__)
-    // GTK+ 1.2 doesn't support this
-    if (wxConfig::Get()->Read(_T("manager_maximized"), long(0)))
-        Maximize();
-#endif
-
     ms_instance = this;
 
     SetToolBar(wxXmlResource::Get()->LoadToolBar(this, _T("manager_toolbar")));
@@ -110,13 +105,28 @@ ManagerFrame::ManagerFrame() :
     UpdateListPrj(last);
     if (m_listPrj->GetCount() > 0)
         UpdateListCat(last);
+
+    wxConfigBase *cfg = wxConfig::Get();
+    int posx = cfg->Read(_T("manager_x"), -1);
+    int posy = cfg->Read(_T("manager_y"), -1);
+    int width = cfg->Read(_T("manager_w"), 400);
+    int height = cfg->Read(_T("manager_h"), 300);
+
+    Move(posx, posy);
+    SetClientSize(width, height);
+
+#if !defined(__WXGTK12__) || defined(__WXGTK20__)
+    // GTK+ 1.2 doesn't support this
+    if (wxConfig::Get()->Read(_T("manager_maximized"), long(0)))
+        Maximize();
+#endif
 }
 
 
 
 ManagerFrame::~ManagerFrame()
 {
-    wxSize sz = GetSize();
+    wxSize sz = GetClientSize();
     wxPoint pos = GetPosition();
     wxConfigBase *cfg = wxConfig::Get();
 
@@ -313,10 +323,9 @@ bool ManagerFrame::EditProject(int id)
     wxXmlResource::Get()->AttachUnknownControl(_T("prj_dirs"),
                 new wxEditableListBox(this, -1, _("Directories:")));
 
-    XRCCTRL(dlg, "prj_name", wxTextCtrl)->SetValue(
-           cfg->Read(key + _T("Name"), _("My Project")));
+    XRCCTRL(dlg, "prj_name", wxTextCtrl)->SetValue(cfg->Read(key + _T("Name")));
 
-    wxString dirs = cfg->Read(key + _T("Dirs"), wxGetCwd());
+    wxString dirs = cfg->Read(key + _T("Dirs"));
     wxArrayString adirs;
     wxStringTokenizer tkn(dirs, wxPATH_SEP);
     while (tkn.HasMoreTokens()) adirs.Add(tkn.GetNextToken());
