@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2000-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: prefsdlg.cpp 1148 2007-06-24 13:42:24Z vaclavslavik $
+ *  $Id: prefsdlg.cpp 1201 2007-11-18 11:59:50Z vaclavslavik $
  *
  *  Preferences settings dialog
  *
@@ -47,6 +47,10 @@
 #include "transmemupd_wizard.h"
 #include "chooselang.h"
 
+#ifdef USE_SPARKLE
+#include "osx/userdefaults.h"
+#endif // USE_SPARKLE
+
 PreferencesDialog::PreferencesDialog(wxWindow *parent)
 {
     wxXmlResource::Get()->LoadDialog(this, parent, _T("preferences"));
@@ -118,7 +122,7 @@ void PreferencesDialog::TransferTo(wxConfigBase *cfg)
                 cfg->Read(_T("open_editor_immediately"), (long)false));
     XRCCTRL(*this, "keep_crlf", wxCheckBox)->SetValue(
                 (bool)cfg->Read(_T("keep_crlf"), true));
-#if USE_SPELLCHECKING
+#ifdef USE_SPELLCHECKING
     XRCCTRL(*this, "enable_spellchecking", wxCheckBox)->SetValue(
                 (bool)cfg->Read(_T("enable_spellchecking"), true));
 #endif
@@ -171,6 +175,11 @@ void PreferencesDialog::TransferTo(wxConfigBase *cfg)
     XRCCTRL(*this, "tm_automatic", wxCheckBox)->SetValue(
                 cfg->Read(_T("use_tm_when_updating"), true));
 #endif
+
+#ifdef USE_SPARKLE
+    XRCCTRL(*this, "auto_updates", wxCheckBox)->SetValue(
+                UserDefaults::GetBoolValue("SUCheckAtStartup"));
+#endif // USE_SPARKLE
 }
  
             
@@ -196,7 +205,7 @@ void PreferencesDialog::TransferFrom(wxConfigBase *cfg)
                 XRCCTRL(*this, "open_editor_immediately", wxCheckBox)->GetValue());
     cfg->Write(_T("keep_crlf"), 
                 XRCCTRL(*this, "keep_crlf", wxCheckBox)->GetValue());
-#if USE_SPELLCHECKING
+#ifdef USE_SPELLCHECKING
     cfg->Write(_T("enable_spellchecking"), 
                 XRCCTRL(*this, "enable_spellchecking", wxCheckBox)->GetValue());
 #endif
@@ -210,7 +219,7 @@ void PreferencesDialog::TransferFrom(wxConfigBase *cfg)
     cfg->Write(_T("custom_font_text_name"),
                 XRCCTRL(*this, "fontname_text", wxTextCtrl)->GetValue());
  
-    static wxChar *formats[] = 
+    static const wxChar *formats[] = 
         { _T("unix"), _T("win"), _T("mac"), _T("native") };
     cfg->Write(_T("crlf_format"), formats[
                 XRCCTRL(*this, "crlf_format", wxChoice)->GetSelection()]);
@@ -236,6 +245,11 @@ void PreferencesDialog::TransferFrom(wxConfigBase *cfg)
     cfg->Write(_T("use_tm_when_updating"), 
                 XRCCTRL(*this, "tm_automatic", wxCheckBox)->GetValue());
 #endif
+
+#ifdef USE_SPARKLE
+    UserDefaults::SetBoolValue("SUCheckAtStartup",
+                XRCCTRL(*this, "auto_updates", wxCheckBox)->GetValue());
+#endif // USE_SPARKLE
 }
 
 
