@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2001-2007 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmem.cpp 1096 2007-06-12 11:41:10Z vaclavslavik $
+ *  $Id: transmem.cpp 1177 2007-10-03 09:50:27Z vaclavslavik $
  *
  *  Translation memory database
  *
@@ -29,6 +29,7 @@
 
 #include <wx/wxprec.h>
 
+#include <set>
 
 /** \page db_desc Translation Memory Algorithms
 
@@ -724,10 +725,13 @@ static inline wxString GetDBPath(const wxString& p, const wxString& l)
 
 
 
+namespace
+{
 
-#include <wx/listimpl.cpp>
-WX_DEFINE_LIST(TranslationMemoriesList);
-TranslationMemoriesList TranslationMemory::ms_instances;
+typedef std::set<TranslationMemory*> TranslationMemories;
+TranslationMemories ms_instances;
+
+} // anonymous namespace
 
 /*static*/ TranslationMemory *TranslationMemory::Create(
                       const wxString& language, const wxString& path)
@@ -743,7 +747,7 @@ TranslationMemoriesList TranslationMemory::ms_instances;
     }
     dbPath += _T('/');
 
-    for (TranslationMemoriesList::const_iterator i = ms_instances.begin();
+    for (TranslationMemories::const_iterator i = ms_instances.begin();
          i != ms_instances.end(); ++i)
     {
         TranslationMemory *mem = *i;
@@ -761,8 +765,18 @@ TranslationMemoriesList TranslationMemory::ms_instances;
         delete tm;
         return NULL;
     }
-    else
-        return tm;
+
+    ms_instances.insert(tm);
+    return tm;
+}
+
+void TranslationMemory::Release()
+{
+    if (--m_refCnt == 0)
+    {
+        ms_instances.erase(this);
+        delete this;
+    }
 }
 
 TranslationMemory::TranslationMemory(const wxString& language, 
