@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmemupd.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: transmemupd.cpp 1293 2008-02-21 09:31:23Z vaclavslavik $
  *
  *  Translation memory database updater
  *
@@ -234,7 +234,7 @@ bool TranslationMemoryUpdater::UpdateFromCatalog(const wxString& filename)
     size_t cnt = cat.GetCount();
     for (size_t i = 0; i < cnt; i++)
     {
-        CatalogData &dt = cat[i];
+        CatalogItem &dt = cat[i];
         if (!dt.IsTranslated() || dt.IsFuzzy()) continue;
         if (!m_mem->Store(dt.GetString(), dt.GetTranslation())) 
             return false;
