@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmemupd_wizard.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id: transmemupd_wizard.cpp 1276 2008-01-15 19:47:13Z vaclavslavik $
  *
  *  Translation memory database update wizard
  *
@@ -143,11 +143,7 @@ private:
 #else
                    _("Translation files (*.po;*.mo)|*.po;*.mo"), 
 #endif
-#if wxCHECK_VERSION(2,8,0)
                          wxFD_OPEN | wxFD_MULTIPLE);
-#else
-                         wxOPEN | wxMULTIPLE);
-#endif
         if (dlg.ShowModal() == wxID_OK)
         {
             wxArrayString f, f2;
